.code-editor {
    display: flex;
    font-family: monospace;
    border: 1px solid #ccc;
    padding: 10px;
    background-color: #f9f9f9;
}

.line-numbers {
    padding-right: 10px;
    text-align: right;
    user-select: none;
    color: #888;
}

.code-editor textarea {
    flex: 1;
    border: none;
    outline: none;
    resize: none;
    background-color: transparent;
    font-family: monospace;
    font-size: 16px;
    line-height: 1.5;
}

.CodeMirror {
    border: 1px solid #ddd;
    height: auto;
}
