{% if widget.is_initial %}
    <label style="margin-bottom: 0">{{ widget.initial_text }}: <a href="{{ widget.value.url }}">{{ widget.value }}</a></label>
    {% if not widget.required %}
        <div style="{{ clear__style }}">
            <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}"{% if widget.attrs.disabled %} disabled{% endif %}{% if widget.attrs.checked %} checked{% endif %}>
            <label for="{{ widget.checkbox_id }}">{{ widget.clear_checkbox_label }}</label>{% endif %}
        </div>
    <label>{{ widget.input_text }}:</label><br>{% endif %}
<input type="{{ widget.type }}" name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %}>
