# Generated by Django 5.1.6 on 2025-04-15 14:00

import hrendjango.models.mixins
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ImageMediaFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True, verbose_name='Уникальный идентификатор')),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name='Дата создания')),
                ('date_update', models.DateTimeField(auto_now=True, verbose_name='Дата изменения')),
                ('filename', models.CharField(max_length=255, verbose_name='Имя файла')),
                ('file', models.ImageField(upload_to='images/', verbose_name='Изображение')),
            ],
            options={
                'verbose_name': 'изображение',
                'verbose_name_plural': 'Изображения',
                'abstract': False,
                'swappable': 'HRENDJANGO_IMAGE_MODEL',
            },
            bases=(hrendjango.models.mixins.DeleteFilesMixin, models.Model),
        ),
        migrations.CreateModel(
            name='MediaFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(upload_to='files/', verbose_name='Файл')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, unique=True, verbose_name='Уникальный идентификатор')),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name='Дата создания')),
                ('date_update', models.DateTimeField(auto_now=True, verbose_name='Дата изменения')),
                ('filename', models.CharField(max_length=255, verbose_name='Имя файла')),
            ],
            options={
                'verbose_name': 'файл',
                'verbose_name_plural': 'Файлы',
                'abstract': False,
                'swappable': 'HRENDJANGO_FILE_MODEL',
            },
            bases=(hrendjango.models.mixins.DeleteFilesMixin, models.Model),
        ),
    ]
